==> cinemate-0.0.4.zip: cinemate-0.0.4/cinemate/lists.py <==
#coding=utf-8
from six import u


countries = {
    'austria': u('Австрия'),
    'azerbaijan': u('Азербайджан'),
    'albania': u('Албания'),
    'algeria': u('Алжир'),
    'argentina': u('Аргентина'),
    'armenia': u('Армения'),
    'aruba': u('Аруба'),
    'afghanistan': u('Афганистан'),
    'bahamas': u('Багамы'),
    'bangladesh': u('Бангладеш'),
    'barbados': u('Барбадос'),
    'bahrain': u('Бахрейн'),
    'belarus': u('Беларусь'),
    'belgium': u('Бельгия'),
    'ivory-coast': u('Берег Слоновой Кости'),
    'bulgaria': u('Болгария'),
    'bolivia': u('Боливия'),
    'bosnia-and-herzegovina': u('Босния-Герцеговина'),
    'botswana': u('Ботсвана'),
    'brazil': u('Бразилия'),
    'burkina-faso': u('Буркина-Фасо'),
    'bhutan': u('Бутан'),
    'uk': u('Великобритания'),
    'hungary': u('Венгрия'),
    'venezuela': u('Венесуэла'),
    'vietnam': u('Вьетнам'),
    'haiti': u('Гаити'),
    'ghana': u('Гана'),
    'guatemala': u('Гватемала'),
    'germany': u('Германия'),
    'east-germany': u('Германия (ГДР)'),
    'west-germany': u('Германия (ФРГ)'),
    'honduras': u('Гондурас'),
    'hong-kong': u('Гонконг'),
    'greenland': u('Гренландия'),
    'greece': u('Греция'),
    'georgia': u('Грузия'),
    'denmark': u('Дания'),
    'dominican-republic': u('Доминиканская Республика'),
    'egypt': u('Египет'),
    'zambia': u('Замбия'),
    'zimbabwe': u('Зимбабве'),
    'israel': u('Израиль'),
    'india': u('Индия'),
    'indonesia': u('Индонезия'),
    'jordan': u('Иордания'),
    'iraq': u('Ирак'),
    'iran': u('Иран'),
    'ireland': u('Ирландия'),
    'iceland': u('Исландия'),
    'spain': u('Испания'),
    'italy': u('Италия'),
    'yemen': u('Йемен'),
    'cape-verde': u('Кабо-Верде'),
    'kazakhstan': u('Казахстан'),
    'cambodia': u('Камбоджа'),
    'cameroon': u('Камерун'),
    'canada': u('Канада'),
    'qatar': u('Катар'),
    'kenya': u('Кения'),
    'cyprus': u('Кипр'),
    'china': u('Китай'),
    'colombia': u('Колумбия'),
    'south-korea': u('Корея Южная'),
    'costa-rica': u('Коста-Рика'),
    'cuba': u('Куба'),
    'kuwait': u('Кувейт'),
    'kyrgyzstan': u('Кыргызстан'),
    'laos': u('Лаос'),
    'latvia': u('Латвия'),
    'lesotho': u('Лесото'),
    'liberia': u('Либерия'),
    'lebanon': u('Ливан'),
    'libya': u('Ливия'),
    'lithuania': u('Литва'),
    'liechtenstein': u('Лихтенштейн'),
    'luxembourg': u('Люксембург'),
    'mauritania': u('Мавритания'),
    'macau': u('Макао'),
    'macedonia': u('Македония'),
    'malaysia': u('Малайзия'),
    'mali': u('Мали'),
    'malta': u('Мальта'),
    'morocco': u('Марокко'),
    'mexico': u('Мексика'),
    'mozambique': u('Мозамбик'),
    'moldova': u('Молдова'),
    'monaco': u('Монако'),
    'mongolia': u('Монголия'),
    'namibia': u('Намибия'),
    'nepal': u('Непал'),
    'nigeria': u('Нигерия'),
    'netherlands': u('Нидерланды'),
    'nicaragua': u('Никарагуа'),
    'new-zealand': u('Новая Зеландия'),
    'norway': u('Норвегия'),
    'united-arab-emirates': u('ОАЭ'),
    'oman': u('Оман'),
    'pakistan': u('Пакистан'),
    'palestine': u('Палестина'),
    'panama': u('Панама'),
    'paraguay': u('Парагвай'),
    'peru': u('Перу'),
    'poland': u('Польша'),
    'portugal': u('Португалия'),
    'puerto-rico': u('Пуэрто-Рико'),
    'republic-of-macedonia': u('Республика Македония'),
    'russian-empire': u('Российская империя'),
    'russia': u('Россия'),
    'romania': u('Румыния'),
    'saudi-arabia': u('Саудовская Аравия'),
    'north-korea': u('Северная Корея'),
    'senegal': u('Сенегал'),
    'serbia': u('Сербия'),
    'serbia-and-montenegro': u('Сербия и Черногория'),
    'singapore': u('Сингапур'),
    'syria': u('Сирия'),
    'slovakia': u('Словакия'),
    'slovenia': u('Словения'),
    'somalia': u('Сомали'),
    'federal-republic-yugoslavia': u('Союзная Республика Югославия'),
    'soviet-union': u('СССР'),
    'usa': u('США'),
    'tajikistan': u('Таджикистан'),
    'thailand': u('Таиланд'),
    'taiwan': u('Тайвань'),
    'tanzania': u('Танзания'),
    'trinidad-and-tobago': u('Тринидад и Тобаго'),
    'tunisia': u('Тунис'),
    'turkmenistan': u('Туркменистан'),
    'turkey': u('Турция'),
    'uzbekistan': u('Узбекистан'),
    'ukraine': u('Украина'),
    'uruguay': u('Уругвай'),
    'faroe-islands': u('Фарерские острова'),
    'philippines': u('Филиппины'),
    'finland': u('Финляндия'),
    'france': u('Франция'),
    'croatia': u('Хорватия'),
    'chad': u('Чад'),
    'montenegro': u('Черногория'),
    'czech-republic': u('Чехия'),
    'czechoslovakia': u('Чехословакия'),
    'chile': u('Чили'),
    'switzerland': u('Швейцария'),
    'sweden': u('Швеция'),
    'sri-lanka': u('Шри-Ланка'),
    'ecuador': u('Эквадор'),
    'estonia': u('Эстония'),
    'ethiopia': u('Эфиопия'),
    'south-africa': u('ЮАР'),
    'yugoslavia': u('Югославия'),
    'jamaica': u('Ямайка'),
    'japan': u('Япония'),
}


genres = {
    'anime': u('аниме'),
    'biography': u('биография'),
    'action': u('боевик'),
    'western': u('вестерн'),
    'war': u('военный'),
    'mystery': u('детектив'),
    'children': u('детский'),
    'adult': u('для взрослых'),
    'documentary': u('документальный'),
    'drama': u('драма'),
    'history': u('история'),
    'comedy': u('комедия'),
    'concert': u('концерт'),
    'short': u('короткометражка'),
    'crime': u('криминал'),
    'romance': u('мелодрама'),
    'music': u('музыка'),
    'animation': u('мультфильм'),
    'musical': u('мюзикл'),
    'news': u('новости'),
    'adventure': u('приключения'),
    'reality-tv': u('реалити шоу'),
    'family': u('семейный'),
    'sport': u('спорт'),
    'game-show': u('телеигра'),
    'talk-show': u('ток-шоу'),
    'thriller': u('триллер'),
    'horror': u('ужасы'),
    'sci-fi': u('фантастика'),
    'film-noir': u('фильм-нуар'),
    'fantasy': u('фэнтези'),
}

==> cinemate-0.0.5.zip: cinemate-0.0.5/cinemate/lists.py <==
#coding=utf-8
"""
    cinemate.lists
    ~~~~~~~~~~~~~~~~~

    Модуль содержит словари countries, genres для получения slug

"""
from six import u

# список стран http://cinemate.cc/movie/country/
countries = {
    'austria': u('Австрия'),
    'azerbaijan': u('Азербайджан'),
    'albania': u('Албания'),
    'algeria': u('Алжир'),
    'argentina': u('Аргентина'),
    'armenia': u('Армения'),
    'aruba': u('Аруба'),
    'afghanistan': u('Афганистан'),
    'bahamas': u('Багамы'),
    'bangladesh': u('Бангладеш'),
    'barbados': u('Барбадос'),
    'bahrain': u('Бахрейн'),
    'belarus': u('Беларусь'),
    'belgium': u('Бельгия'),
    'ivory-coast': u('Берег Слоновой Кости'),
    'bulgaria': u('Болгария'),
    'bolivia': u('Боливия'),
    'bosnia-and-herzegovina': u('Босния-Герцеговина'),
    'botswana': u('Ботсвана'),
    'brazil': u('Бразилия'),
    'burkina-faso': u('Буркина-Фасо'),
    'bhutan': u('Бутан'),
    'uk': u('Великобритания'),
    'hungary': u('Венгрия'),
    'venezuela': u('Венесуэла'),
    'vietnam': u('Вьетнам'),
    'haiti': u('Гаити'),
    'ghana': u('Гана'),
    'guatemala': u('Гватемала'),
    'germany': u('Германия'),
    'east-germany': u('Германия (ГДР)'),
    'west-germany': u('Германия (ФРГ)'),
    'honduras': u('Гондурас'),
    'hong-kong': u('Гонконг'),
    'greenland': u('Гренландия'),
    'greece': u('Греция'),
    'georgia': u('Грузия'),
    'denmark': u('Дания'),
    'dominican-republic': u('Доминиканская Республика'),
    'egypt': u('Египет'),
    'zambia': u('Замбия'),
    'zimbabwe': u('Зимбабве'),
    'israel': u('Израиль'),
    'india': u('Индия'),
    'indonesia': u('Индонезия'),
    'jordan': u('Иордания'),
    'iraq': u('Ирак'),
    'iran': u('Иран'),
    'ireland': u('Ирландия'),
    'iceland': u('Исландия'),
    'spain': u('Испания'),
    'italy': u('Италия'),
    'yemen': u('Йемен'),
    'cape-verde': u('Кабо-Верде'),
    'kazakhstan': u('Казахстан'),
    'cambodia': u('Камбоджа'),
    'cameroon': u('Камерун'),
    'canada': u('Канада'),
    'qatar': u('Катар'),
    'kenya': u('Кения'),
    'cyprus': u('Кипр'),
    'china': u('Китай'),
    'colombia': u('Колумбия'),
    'south-korea': u('Корея Южная'),
    'costa-rica': u('Коста-Рика'),
    'cuba': u('Куба'),
    'kuwait': u('Кувейт'),
    'kyrgyzstan': u('Кыргызстан'),
    'laos': u('Лаос'),
    'latvia': u('Латвия'),
    'lesotho': u('Лесото'),
    'liberia': u('Либерия'),
    'lebanon': u('Ливан'),
    'libya': u('Ливия'),
    'lithuania': u('Литва'),
    'liechtenstein': u('Лихтенштейн'),
    'luxembourg': u('Люксембург'),
    'mauritania': u('Мавритания'),
    'macau': u('Макао'),
    'macedonia': u('Македония'),
    'malaysia': u('Малайзия'),
    'mali': u('Мали'),
    'malta': u('Мальта'),
    'morocco': u('Марокко'),
    'mexico': u('Мексика'),
    'mozambique': u('Мозамбик'),
    'moldova': u('Молдова'),
    'monaco': u('Монако'),
    'mongolia': u('Монголия'),
    'namibia': u('Намибия'),
    'nepal': u('Непал'),
    'nigeria': u('Нигерия'),
    'netherlands': u('Нидерланды'),
    'nicaragua': u('Никарагуа'),
    'new-zealand': u('Новая Зеландия'),
    'norway': u('Норвегия'),
    'united-arab-emirates': u('ОАЭ'),
    'oman': u('Оман'),
    'pakistan': u('Пакистан'),
    'palestine': u('Палестина'),
    'panama': u('Панама'),
    'paraguay': u('Парагвай'),
    'peru': u('Перу'),
    'poland': u('Польша'),
    'portugal': u('Португалия'),
    'puerto-rico': u('Пуэрто-Рико'),
    'republic-of-macedonia': u('Республика Македония'),
    'russian-empire': u('Российская империя'),
    'russia': u('Россия'),
    'romania': u('Румыния'),
    'saudi-arabia': u('Саудовская Аравия'),
    'north-korea': u('Северная Корея'),
    'senegal': u('Сенегал'),
    'serbia': u('Сербия'),
    'serbia-and-montenegro': u('Сербия и Черногория'),
    'singapore': u('Сингапур'),
    'syria': u('Сирия'),
    'slovakia': u('Словакия'),
    'slovenia': u('Словения'),
    'somalia': u('Сомали'),
    'federal-republic-yugoslavia': u('Союзная Республика Югославия'),
    'soviet-union': u('СССР'),
    'usa': u('США'),
    'tajikistan': u('Таджикистан'),
    'thailand': u('Таиланд'),
    'taiwan': u('Тайвань'),
    'tanzania': u('Танзания'),
    'trinidad-and-tobago': u('Тринидад и Тобаго'),
    'tunisia': u('Тунис'),
    'turkmenistan': u('Туркменистан'),
    'turkey': u('Турция'),
    'uzbekistan': u('Узбекистан'),
    'ukraine': u('Украина'),
    'uruguay': u('Уругвай'),
    'faroe-islands': u('Фарерские острова'),
    'philippines': u('Филиппины'),
    'finland': u('Финляндия'),
    'france': u('Франция'),
    'croatia': u('Хорватия'),
    'chad': u('Чад'),
    'montenegro': u('Черногория'),
    'czech-republic': u('Чехия'),
    'czechoslovakia': u('Чехословакия'),
    'chile': u('Чили'),
    'switzerland': u('Швейцария'),
    'sweden': u('Швеция'),
    'sri-lanka': u('Шри-Ланка'),
    'ecuador': u('Эквадор'),
    'estonia': u('Эстония'),
    'ethiopia': u('Эфиопия'),
    'south-africa': u('ЮАР'),
    'yugoslavia': u('Югославия'),
    'jamaica': u('Ямайка'),
    'japan': u('Япония'),
}

# список жанров http://cinemate.cc/movie/genre/
genres = {
    'anime': u('аниме'),
    'biography': u('биография'),
    'action': u('боевик'),
    'western': u('вестерн'),
    'war': u('военный'),
    'mystery': u('детектив'),
    'children': u('детский'),
    'adult': u('для взрослых'),
    'documentary': u('документальный'),
    'drama': u('драма'),
    'history': u('история'),
    'comedy': u('комедия'),
    'concert': u('концерт'),
    'short': u('короткометражка'),
    'crime': u('криминал'),
    'romance': u('мелодрама'),
    'music': u('музыка'),
    'animation': u('мультфильм'),
    'musical': u('мюзикл'),
    'news': u('новости'),
    'adventure': u('приключения'),
    'reality-tv': u('реалити шоу'),
    'family': u('семейный'),
    'sport': u('спорт'),
    'game-show': u('телеигра'),
    'talk-show': u('ток-шоу'),
    'thriller': u('триллер'),
    'horror': u('ужасы'),
    'sci-fi': u('фантастика'),
    'film-noir': u('фильм-нуар'),
    'fantasy': u('фэнтези'),
}
